<?php

defined('ABSPATH') || exit;

class Searchanise
{
    private $lang_code;

    public function __construct($lang_code) {
        $this->lang_code = $lang_code;

        if (
            is_admin()
            || ApiSe::getInstance()->getModuleStatus() != 'Y'
            || empty($lang_code)
            || ApiSe::getInstance()->getApiKey($lang_code) == ''
            || !ApiSe::getInstance()->isSearchAllowed($lang_code)
        ) {
            return false;
        }
        add_action('wp_enqueue_scripts', array($this, 'loadSearchWidget'));

        // Workaround to not use permalinks on search results page because Searchanise reads query params directly
        // and permalinks redirect breaks se widget js logic
        if (ApiSe::getInstance()->isResultWidgetEnabled($this->lang_code)) {
            add_action('wp_loaded', function() {
                global $post;

                if (is_object($post) && $post->ID == SeInstaller::createSearchResultsPage()) {
                    remove_filter('template_redirect', 'redirect_canonical');
                }
            });
        }

        add_action('pre_get_posts', array($this, 'excludeResultWidgetFromSearch'));
    }

    /**
     * Exclude search result page from search
     * 
     * @param mixed $query Search query
     */
    public function excludeResultWidgetFromSearch($query)
    {
        if (
            ApiSe::getInstance()->isResultWidgetEnabled($this->lang_code)
            && !$query->is_admin
            && $query->is_search
            && $query->is_main_query()
        ) {
            $post_id = SeInstaller::createSearchResultsPage();
            $query->set('post__not_in', array($post_id));
        }
    }

    /**
     * Returns search results page url
     * 
     * @return string
     */
    private function getSearchResultPageUrl()
    {
        if (!ApiSe::getInstance()->isResultWidgetEnabled($this->lang_code)) {
            return '';
        }

        $se_searchanise_url = '';
        $se_page_id = SeInstaller::createSearchResultsPage();

        if (!empty($se_page_id)) {
            $se_page = get_post($se_page_id);

            if (!empty($se_page)) {
                $se_searchanise_url = get_permalink($se_page->ID);
            }
        }

        /**
         * Filters Searchanise results page
         * 
         * @param string $se_searchanise_url Page url
         * @param string $lang_code Lang code
         */
        return apply_filters('se_get_search_results_page_url', $se_searchanise_url, $this->lang_code);
    }

    /**
     * Returns fallback url for search results
     * 
     * @return string
     */
    private function getFallbackUrl()
    {
        return ApiSe::getInstance()->getFrontendUrl($this->lang_code, array(
            'post_type' => 'product',
            's'         => '',
        ));
    }

    /**
     * Returns currency position
     * 
     * @return boolean
     */
    private function getCurrencyPositionAfter()
    {
        $currency_pos = get_option('woocommerce_currency_pos');

        switch($currency_pos) {
            case 'left':
            case 'left_space':
                return false;

            case 'right':
            case 'right_space':
                return true;

            default:
                return false;
        }
    }

    /**
     * Loads search widget assets
     */
    public function loadSearchWidget()
    {
        $se_searchanise_url = $this->getSearchResultPageUrl();
        $se_widgets_file_path = SE_BASE_DIR . '/assets/js/se-widgets.js';

        $se_options = array(
            'version'                       => SE_VERSION,
            'host'                          => is_ssl() ? str_replace('http://', 'https://', SE_SERVICE_URL) : SE_SERVICE_URL,
            'api_key'                       => ApiSe::getInstance()->getApiKey($this->lang_code),
            'symbol'                        => get_woocommerce_currency_symbol(),
            'decimals'                      => wc_get_price_decimals(),
            'decimals_separator'            => wc_get_price_decimal_separator(),
            'thousands_separator'           => wc_get_price_thousand_separator(),
            'currency_position_after'       => $this->getCurrencyPositionAfter(),
            'search_input'                  => ApiSe::getInstance()->getSearchInputSelector(),
            'results_form_path'             => $se_searchanise_url,
            'results_fallback_url'          => $this->getFallbackUrl(),
            'rate'                          => ApiSe::getInstance()->getCurrencyRate(),
            'hide_out_of_stock_products'    => 'yes' === get_option('woocommerce_hide_out_of_stock_items') ? 'Y' : 'N',
            'cur_label_for_usergroup'       => ApiSe::getInstance()->getCurLabelForPricesUsergroup(),
            'usergroup_ids'                 => implode('|', ApiSe::getInstance()->getCurrentUsergroupIds()),
        );

        // Do not include search in admin toolbar
        wc_enqueue_js("jQuery('#wpadminbar').find('" . html_entity_decode(ApiSe::getInstance()->getSearchInputSelector()) . "').addClass('snize-exclude-input')");

        // Loading searchanise widgets
        $se_options = apply_filters('se_load_search_widgets', $se_options);
        wp_register_script('se-widgets', plugins_url($se_widgets_file_path), array('jquery'), SE_PLUGIN_VERSION, true);
        wp_localize_script('se-widgets', 'SeOptions', $se_options);
        wp_enqueue_script('se-widgets');
    }

    /**
     * Check private key from request
     * 
     * @return boolean
     */
    public function checkPrivateKey()
    {
        static $check = null;
 
        if ($check === null) {
            $parent_private_key = !empty($_REQUEST['parent_private_key']) ? $_REQUEST['parent_private_key'] : '';

            if (
                empty($parent_private_key)
                || ApiSe::getInstance()->getParentPrivateKey() != $parent_private_key
            ) {
                $check == false;
            } else {
                $check = true;
            }
        }

        return $check;
    }
}

add_action('plugins_loaded', function() {
    $GLOBALS['searchanise'] = new Searchanise(get_locale());
});
